@@ -1,7 +1,7 @@
 """forge specific entities class for imported entities
 
 :organization: Logilab
-:copyright: 2006-2011 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2006-2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -12,7 +12,7 @@ from logilab.common.date import nb_open_days
 
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import IFTIndexableAdapter
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 
 from cubes.card.entities import Card as BaseCard
 from cubes.file.entities import File as BaseFile
@@ -140,7 +140,7 @@ class Ticket(ticket.Ticket):
 
     fetch_attrs = ('title', 'type', 'priority', 'load', 'load_left', 'in_state')
     noload_cost = 10
-    skip_copy_for = ticket.Ticket.skip_copy_for + ('done_in',)
+    cw_skip_copy_for = ticket.Ticket.cw_skip_copy_for + [('done_in', 'subject')]
 
     # ticket'specific logic ###################################################
 
