@@ -111,7 +111,9 @@ class SetModificationDateAfterAddComment(Hook):
     """update root entity's modification date after adding a comment"""
     __regid__ = 'set_modification_date_after_comment'
     events = ('after_add_relation',)
-    __select__ = Hook.__select__ & hook.match_rtype('comments',)
+    __select__ = (Hook.__select__ &
+                  hook.match_rtype('comments',
+                                   toetypes=['Ticket', 'Comment']))
 
     def __call__(self):
         entity = self._cw.entity_from_eid(self.eidto)
