@@ -25,12 +25,13 @@ _ = unicode
 
 from yams.buildobjs import (EntityType, RelationDefinition,
                             String, Float, RichString, Bytes)
+from yams.reader import context
 
 from cubicweb.schema import (RQLVocabularyConstraint, RRQLExpression,
                              ERQLExpression, make_workflowable)
 from cubes.localperms import sexpr, xexpr, xrexpr, xperm, restricted_oexpr
 
-from cubes.tracker.schema import Project, Ticket, Version, done_in
+from cubes.tracker.schema import Project, Ticket, Version
 from cubes.file.schema import File
 from cubes.card.schema import Card
 
@@ -53,6 +54,7 @@ Project.get_relations('uses').next().constraints = [
 
 make_workflowable(Project)
 
+done_in = Ticket.get_relation('done_in')
 done_in.__permissions__['delete'] = (
     'managers',
     RRQLExpression('U in_group G, G name "staff", NOT (O in_state ST, ST name "published")'),
@@ -230,9 +232,13 @@ class interested_in(RelationDefinition):
     subject = 'CWUser'
     object = ('Project', 'Ticket')
 
+nosy_list_subjects = ('Email', 'ExtProject', 'Project', 'Version', 'Ticket',
+                      'File', 'Card', 'TestInstance')
+if ('Comment', 'nosy_list', 'CWUser') not in context.defined:
+    nosy_list_subjects += ('Comment', )
+
 class nosy_list(RelationDefinition):
-    subject = ('Email', 'ExtProject', 'Project', 'Version', 'Ticket',
-               'Comment', 'File', 'Card', 'TestInstance')
+    subject = nosy_list_subjects
     object = 'CWUser'
 
 # extra relation definitions ##################################################
