@@ -25,6 +25,13 @@ from cubes.nosylist import views as nosylist
 ONEDAY = timedelta(1)
 
 
+class ForgeTests(TrackerBaseTC):
+    """test forge specific behaviours"""
+
+    def test_schema(self):
+        seealso = self.schema['see_also']
+        self.assert_('Ticket' in seealso.subjects(), seealso.subjects())
+
 class ProjectTC(TrackerBaseTC):
     """Project"""
 
@@ -349,6 +356,20 @@ class TicketTC(TrackerBaseTC):
         self.commit()
         self.assertModificationDateGreater(self.t1, olddate)
 
+    def test_modification_date_not_changed_if_not_ticket(self):
+        # Commentable entities other than tickets should not have their
+        # modification_date updated upon comments. Card is one of these.
+        # Regression test for ticket #2961589.
+        card = self.execute('INSERT Card X: X title "Manaul", P documented_by X'
+                            '   WHERE P is Project').get_entity(0, 0)
+        olddate = datetime.today() - ONEDAY
+        card.set_attributes(modification_date=olddate)
+        self.execute('INSERT Comment C: C content "Typo included", '
+                     '  C comments X WHERE X eid %(x)s', {'x': card.eid})
+        self.commit()
+        card.cw_attr_cache.pop('modification_date', None)
+        self.assertEqual(olddate, card.modification_date)
+
     def test_possible_actions(self):
         req = self.request()
         rset = req.execute('Any X WHERE X is Ticket')
