@@ -22,8 +22,8 @@ class NotificationTC(TrackerBaseTC):
         self.assertEqual([re.sub('#\d+', '#EID', e.subject) for e in MAILBOX],
                           ['[data] New Project: hop',
                            '[data] New Project: hop', # see below
-                           '[hop] New Ticket #EID: one more',
-                           '[hop] new comment for ticket #EID: one more',
+                           '[hop] Ticket added: #EID one more',
+                           '[hop] new comment for Ticket #EID one more',
                            ])
         # test that for new project, recipients are the nosy list (eg creator)
         # *and* default recipients
@@ -51,9 +51,9 @@ class NotificationTC(TrackerBaseTC):
         self.commit()
         self.assertEqual(len(MAILBOX), 2)
         MAILBOX.sort(key=lambda x: x.recipients)
-        self.assertEqual(MAILBOX[0].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
+        self.assertEqual(MAILBOX[0].subject, '[cubicweb] Ticket added: #%s ticket' % ticket.eid)
         self.assertEqual(MAILBOX[0].recipients, ['admin@cwo'])
-        self.assertEqual(MAILBOX[1].subject, '[cubicweb] New Ticket #%s: ticket' % ticket.eid)
+        self.assertEqual(MAILBOX[1].subject, '[cubicweb] Ticket added: #%s ticket' % ticket.eid)
         self.assertEqual(MAILBOX[1].recipients, ['logilabien@logilab.org'])
 
 
