@@ -91,7 +91,7 @@ class ForgeSecurityTC(ForgeSecurityTC):
         # got feedback transition. Got feedback is a 'go back' transition
         self._test_tr_success('staffuser', b.eid, 'wait for feedback')
         self._test_tr_success('prj1developer', b.eid, 'got feedback')
-        b.clear_all_caches()
+        b.cw_clear_all_caches()
         self.assertEqual(b.cw_adapt_to('IWorkflowable').state, 'in-progress')
         # staff/cubicweb developer can modify tickets even once no more in the open state
         cnx = self.mylogin('staffuser')
