@@ -19,7 +19,7 @@ class VersionDocumentItemView(document.VersionDocumentItemView):
         if etadate is None:
             etadate = self._cw._('n/a')
         else:
-            etadate = self.format_date(etadate)
+            etadate = self._cw.format_date(etadate)
         self.field(entity, self._cw._('expected date'), etadate)
 
 
