@@ -112,7 +112,7 @@ class ProjectListView(baseviews.SameETypeListView):
                   is_instance("Project"))
     def call(self, **kwargs):
         # sort by modification date
-        self.cw_rset = self.cw_rset.sorted_rset(lambda e: e.cw_attr_cache['modification_date'],
+        self.cw_rset = self.cw_rset.sorted_rset(lambda e: e.modification_date,
                                                 reverse=True)
         super(ProjectListView, self).call(**kwargs)
 
