@@ -9,7 +9,7 @@ _ = unicode
 
 from logilab.common.decorators import monkeypatch
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.view import EntityView
 from cubicweb.web import uicfg
 from cubicweb.web.views import baseviews, tableview
